==> pgmarket-1.2.6.tar.gz: pgmarket-1.2.6/shopping/complete_order.php <==
<?
/* complete_order.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("../application.inc.php");
require_login();

/* this page will do the CC authentication, so we want to try to prevent
 * people from entering here causually */
$cart_is_empty = $CART->itemcount() == 0;
$order = load_orderinfo();
if ($cart_is_empty || ! $order) {
	header("Location: $CFG->wwwroot");
	die;
}

/*

Se si tratta del pulsante del ContrAssegno, semplicemente e` gia` tutto finito
e bisogna solamente fare cio` che e` descritto nell'if sottostante;
forse conviene mettere qualche controllo sul valore di ritorno di $orderid .

Se si tratta del pulsante relativo alla Carta di Credito, bisogna preparare
le variabili necessarie per preparare la form da sottomettere
al Payment Authorization Service (parte da aggiungere), che corrisponde
a un opportuno template.

*/

if ($paybutton == $Cash_On_Delivery) { // si tratta di un pagamento in contrassegno

	/* we will create the order in our database, then try to authorize the
 	* payment.  if all was successful, the user's order will have been
 	* completed.
 	*/
	$emailbody = "";
	$orderid = create_order_ca($order, &$emailbody);
//	echo "<pre>" . $emailbody . "</pre>";	// usare in caso di test
	mail(
		"$CFG->seller_fullname <$CFG->seller_email>",
		$subject_cash_on_delivery,
		$emailbody,
		"From: $CFG->support");

	$DOC_TITLE = $Order_Completed_Successfully;
	$template_to_show = "templates/".$SESSION["lang"]."/complete_order_success.ihtml";
	$cart_total = $CART->grandtotal;
	/* clear out the shopping cart, so the user doesn't accidentally re-submit
 	* and purchase twice!! */
	$CART->init();
	clear_orderinfo();
	$SESSION["wantsurl"] = "";

} else if ($paybutton == $Credit_Card) {

/////////////////////////////////////////////////////////////////////////
// A PART OF THE CODE HAS BEEN CUT AWAY BECAUSE IT STRICTLY DEPENDS ON
// THE PARTICULAR PAYMENT AUTHORIZATION SERVICE YOU DECIDE TO USE; HENCE,
// IN GENERAL, THE PART OF CODE CUT AWAY WILL NOT BE USEFUL TO YOU
/////////////////////////////////////////////////////////////////////////

	$orderid = create_order_cc($order, $passwordric);
	$DOC_TITLE = $submission_to_banca_sella;
	$template_to_show = "templates/".$SESSION["lang"]."/banca_sella_submit.ihtml";

}

include("$CFG->templatedir"."header.ihtml");
include($template_to_show);
include("$CFG->templatedir"."footer.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function create_order_ca(&$order, &$emailbody) {
/* this function saves this order info the database, it will make one entry
 * in the orders table for the order, and then save the shopping cart
 * contents into the order_items table */
// It also creates the email_body to be sent to the market seller

	global $SESSION, $CART;
	global $myday, $mymonth, $ordersdb;

	/* build the custinfo string */
	$custinfo =
		  $ordersdb[Customer] . " $order->customer\n"
		. $ordersdb[Phone]    . " $order->contact\n"
		. $ordersdb[Address]  . " $order->address" . " $order->number\n"
		. " $order->city\n" . " $order->state\n" . " $order->zip_code\n";

	/* save order information first */

	$Date = $myday[date("w")] . date(" j ") . $mymonth[date("n")] . date(" Y H:i:s");
	$FromIP = getenv("REMOTE_ADDR");
	$Dateusec = gettimeofday();
	$orderid = $Dateusec["sec"].$Dateusec["usec"]."-".$FromIP;

	$qid = db_begin();

	$qid = db_query("
	INSERT INTO ordersca (
		id, username, date, fromip, custinfo, notes, amount, delivery
	) VALUES (
		 '$orderid'
		,'{$SESSION["user"]["username"]}'
		,'$Date'
		,'$FromIP'
		,'$custinfo'
		,'$order->comments'
		,'{$CART->grandtotal}'
		,'{$CART->delivery}'
	)");

	$order_comments = stripslashes ($order->comments);
	$emailbody .= "\n" . $ordersdb[Cash_On_Delivery] . "\n"
		. "\n" . $ordersdb[Order] . " " . $orderid
		. "\n" . $ordersdb[Username] . ": " . $SESSION["user"]["username"]
		. "\n" . $ordersdb[Date] . ": " . $Date
		. "\n" . $ordersdb[Comments] . ":\n" . $order_comments
		. "\n\n" . $ordersdb[TOTAL] . ": " . formatted_price_text ($CART->grandtotal) . "\n";

	/* now add the shopping cart items into the order_items table */
	$qid = get_cart_items();
	$numr = db_num_rows($qid);
        for ($i=0; $i<$numr; $i++) {
		$item = db_fetch_object($qid, $i);
		$ivavalue = get_iva($item->iva_id);
		db_query("
		INSERT INTO order_items (
			order_id, product_id, price, iva, weight, qty
		) VALUES (
			 '$orderid'
			,'$item->id'
			,'$item->price'
			,'$ivavalue'
			,'$item->weight'
			,'{$CART->items["$item->id"]}'
		)");
		$qid_prod_id = db_query("
		SELECT name
		FROM products
		WHERE id = '$item->id'
		");
		$row = db_fetch_object($qid_prod_id, 0);
		$emailbody .= "\n" . $ordersdb[Product] . " " . $item->id . " - " . $row->name
			. "\n" . $ordersdb[Unit_Price] . ": " . formatted_price_text ($item->price)
			. "\n" . $ordersdb[Number_of_items] . ": " . $CART->items["$item->id"] . "\n";
	}

	$qid = db_commit();

	$emailbody .= "\n" . $ordersdb[Delivery] . ": " . formatted_price_text ($CART->delivery);

	return $orderid;
}

function create_order_cc(&$order, $passwordric) {
/* this function saves this order info the database, it will make one entry
 * in the orders table for the order, and then save the shopping cart
 * contents into the order_items table */

	global $SESSION, $CART;
	global $myday, $mymonth, $ordersdb;

	/* build the custinfo string */
	$custinfo =
		  $ordersdb[Customer] . " $order->customer\n"
		. $ordersdb[Phone]    . " $order->contact\n"
		. $ordersdb[Address]  . " $order->address" . " $order->number\n"
		. " $order->city\n" . " $order->state\n" . " $order->zip_code\n";

	/* save order information first */

	$Date = $myday[date("w")] . date(" j ") . $mymonth[date("n")] . date(" Y H:i:s");
	$FromIP = getenv("REMOTE_ADDR");
	$Dateusec = gettimeofday();
	$orderid = $Dateusec["sec"].$Dateusec["usec"]."-".$FromIP;

	$qid = db_begin();

	$qid = db_query("
	INSERT INTO orderscc (
		id, username, date, fromip, custinfo, notes, amount, delivery, otpric
	) VALUES (
		 '$orderid'
		,'{$SESSION["user"]["username"]}'
		,'$Date'
		,'$FromIP'
		,'$custinfo'
		,'$order->comments'
		,'{$CART->grandtotal}'
		,'{$CART->delivery}'
		,'$passwordric'
	)");

	/* now add the shopping cart items into the order_items table */
	$qid = get_cart_items();
	$numr = db_num_rows($qid);
        for ($i=0; $i<$numr; $i++) {
		$item = db_fetch_object($qid, $i);
		$ivavalue = get_iva($item->iva_id);
		db_query("
		INSERT INTO order_items (
			order_id, product_id, price, iva, weight, qty
		) VALUES (
			 '$orderid'
			,'$item->id'
			,'$item->price'
			,'$ivavalue'
			,'$item->weight'
			,'{$CART->items["$item->id"]}'
		)");
	}

	$qid = db_commit();

	return $orderid;
}

?>

==> pgmarket-1.3.2.tar.gz: pgmarket-1.3.2/shopping/complete_order.php <==
<?
/* complete_order.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("../application.inc.php");
require_login();

/* this page will do the CC authentication, so we want to try to prevent
 * people from entering here causually */
$cart_is_empty = $CART->itemcount() == 0;
$order = load_orderinfo();
if ($cart_is_empty || ! $order) {
	header("Location: $CFG->firstpage");
	die;
}

/*

Se si tratta del pulsante del ContrAssegno, semplicemente e` gia` tutto finito
e bisogna solamente fare cio` che e` descritto nell'if sottostante;
forse conviene mettere qualche controllo sul valore di ritorno di $orderid .

Se si tratta del pulsante relativo alla Carta di Credito, bisogna preparare
le variabili necessarie per preparare la form da sottomettere
al Payment Authorization Service (parte da aggiungere), che corrisponde
a un opportuno template.

*/

if ($paybutton == $Cash_On_Delivery) { // si tratta di un pagamento in contrassegno

	/* we will create the order in our database, then try to authorize the
 	* payment.  if all was successful, the user's order will have been
 	* completed.
 	*/
	$emailbody = "";
	$orderid = create_order_ca($order, &$emailbody);
//	echo "<pre>" . $emailbody . "</pre>";	// usare in caso di test
	mail(
		"$CFG->seller_fullname <$CFG->seller_email>",
		$subject_cash_on_delivery,
		$emailbody,
		"From: $CFG->support");

	$DOC_TITLE = $Order_Completed_Successfully;
	$template_to_show = "templates/".$SESSION["lang"]."/complete_order_success.ihtml";
	$cart_total = $CART->grandtotal;
	/* clear out the shopping cart, so the user doesn't accidentally re-submit
 	* and purchase twice!! */
	$CART->init();
	clear_orderinfo();
	$SESSION["wantsurl"] = "";

} else if ($paybutton == $Credit_Card) {

/////////////////////////////////////////////////////////////////////////
// A PART OF THE CODE HAS BEEN CUT AWAY BECAUSE IT STRICTLY DEPENDS ON
// THE PARTICULAR PAYMENT AUTHORIZATION SERVICE YOU DECIDE TO USE; HENCE,
// IN GENERAL, THE PART OF CODE CUT AWAY WILL NOT BE USEFUL TO YOU
/////////////////////////////////////////////////////////////////////////

	$orderid = create_order_cc($order, $passwordric);
	$DOC_TITLE = $submission_to_banca_sella;
	$template_to_show = "templates/".$SESSION["lang"]."/banca_sella_submit.ihtml";

}

include("$CFG->templatedir"."header.ihtml");
include($template_to_show);
include("$CFG->templatedir"."footer.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function create_order_ca(&$order, &$emailbody) {
/* this function saves this order info the database, it will make one entry
 * in the orders table for the order, and then save the shopping cart
 * contents into the order_items table */
// It also creates the email_body to be sent to the market seller

	global $SESSION, $CART;
	global $myday, $mymonth, $ordersdb;

	/* build the custinfo string */
	$custinfo =
		  $ordersdb[Customer] . " $order->customer\n"
		. $ordersdb[Phone]    . " $order->contact\n"
		. $ordersdb[Address]  . " $order->address" . " $order->number\n"
		. " $order->city\n" . " $order->state\n" . " $order->zip_code\n";

	/* save order information first */

	$Date = $myday[date("w")] . date(" j ") . $mymonth[date("n")] . date(" Y H:i:s");
	$FromIP = getenv("REMOTE_ADDR");
	$Dateusec = gettimeofday();
	$orderid = $Dateusec["sec"].$Dateusec["usec"]."-".$FromIP;

	$qid = db_begin();

	$qid = db_query("
	INSERT INTO ordersca (
		id, username, date, fromip, custinfo, notes, amount, delivery
	) VALUES (
		 '$orderid'
		,'{$SESSION["user"]["username"]}'
		,'$Date'
		,'$FromIP'
		,'$custinfo'
		,'$order->comments'
		,'{$CART->grandtotal}'
		,'{$CART->delivery}'
	)");

	$order_comments = stripslashes ($order->comments);
	$emailbody .= "\n" . $ordersdb[Cash_On_Delivery] . "\n"
		. "\n" . $ordersdb[Order] . " " . $orderid
		. "\n" . $ordersdb[Username] . ": " . $SESSION["user"]["username"]
		. "\n" . $ordersdb[Date] . ": " . $Date
		. "\n" . $ordersdb[Comments] . ":\n" . $order_comments
		. "\n\n" . $ordersdb[TOTAL] . ": " . formatted_price_text ($CART->grandtotal) . "\n";

	/* now add the shopping cart items into the order_items table */
	$qid = get_cart_items();
	$numr = db_num_rows($qid);
        for ($i=0; $i<$numr; $i++) {
		$item = db_fetch_object($qid, $i);
		$ivavalue = get_iva($item->iva_id);
		db_query("
		INSERT INTO order_items (
			order_id, product_id, price, iva, weight, qty
		) VALUES (
			 '$orderid'
			,'$item->id'
			,'$item->price'
			,'$ivavalue'
			,'$item->weight'
			,'{$CART->items["$item->id"]}'
		)");
		$qid_prod_id = db_query("
		SELECT name
		FROM products
		WHERE id = '$item->id'
		");
		$row = db_fetch_object($qid_prod_id, 0);
		$emailbody .= "\n" . $ordersdb[Product] . " " . $item->id . " - " . $row->name
			. "\n" . $ordersdb[Unit_Price] . ": " . formatted_price_text ($item->price)
			. "\n" . $ordersdb[Number_of_items] . ": " . $CART->items["$item->id"] . "\n";
	}

	$qid = db_commit();

	$emailbody .= "\n" . $ordersdb[Delivery] . ": " . formatted_price_text ($CART->delivery);

	return $orderid;
}

function create_order_cc(&$order, $passwordric) {
/* this function saves this order info the database, it will make one entry
 * in the orders table for the order, and then save the shopping cart
 * contents into the order_items table */

	global $SESSION, $CART;
	global $myday, $mymonth, $ordersdb;

	/* build the custinfo string */
	$custinfo =
		  $ordersdb[Customer] . " $order->customer\n"
		. $ordersdb[Phone]    . " $order->contact\n"
		. $ordersdb[Address]  . " $order->address" . " $order->number\n"
		. " $order->city\n" . " $order->state\n" . " $order->zip_code\n";

	/* save order information first */

	$Date = $myday[date("w")] . date(" j ") . $mymonth[date("n")] . date(" Y H:i:s");
	$FromIP = getenv("REMOTE_ADDR");
	$Dateusec = gettimeofday();
	$orderid = $Dateusec["sec"].$Dateusec["usec"]."-".$FromIP;

	$qid = db_begin();

	$qid = db_query("
	INSERT INTO orderscc (
		id, username, date, fromip, custinfo, notes, amount, delivery, otpric
	) VALUES (
		 '$orderid'
		,'{$SESSION["user"]["username"]}'
		,'$Date'
		,'$FromIP'
		,'$custinfo'
		,'$order->comments'
		,'{$CART->grandtotal}'
		,'{$CART->delivery}'
		,'$passwordric'
	)");

	/* now add the shopping cart items into the order_items table */
	$qid = get_cart_items();
	$numr = db_num_rows($qid);
        for ($i=0; $i<$numr; $i++) {
		$item = db_fetch_object($qid, $i);
		$ivavalue = get_iva($item->iva_id);
		db_query("
		INSERT INTO order_items (
			order_id, product_id, price, iva, weight, qty
		) VALUES (
			 '$orderid'
			,'$item->id'
			,'$item->price'
			,'$ivavalue'
			,'$item->weight'
			,'{$CART->items["$item->id"]}'
		)");
	}

	$qid = db_commit();

	return $orderid;
}

?>
